e-drone


* Install
> pip install e_drone
> pip --no-cache-dir install e_drone

* Upgrade
> pip install --upgrade e_drone

* Uninstall
> pip uninstall e_drone



PyPI
https://pypi.python.org/pypi/e_drone


Documents for E-Drone python library.
https://byrobot.github.io/documents/kr/products/e_drone/library/python/e_drone/


BYROBOT Dev
http://dev.byrobot.co.kr/


Forum
https://groups.google.com/d/forum/byrobot


BYROBOT